@@ -11,7 +11,7 @@ import pandas as pd
 
 class GSDBS:
     def __init__(self):
-        self.version = "0.1.11"
+        self.version = "0.1.12"
         self.credentials = None
         self.accessToken = None
         self.dtablename = None
@@ -42,8 +42,9 @@ class GSDBS:
                     or ('client_secret' not in self.credentials.keys())):
                 print('Error in credentials')
                 return
-        except:
+        except Exception as e:
             print('Missing Credentials')
+            print(e)
         return
 
     def getToken(self):
@@ -142,16 +143,28 @@ class GSDBS:
     def getGSDBSType(self, pyType):
         if pyType == "object":
             return "STRING"
+        elif pyType == "str":
+            return "STRING"
+        elif pyType == "int":
+            return "INTEGER"
+        elif pyType == "integer":
+            return "INTEGER"
         elif pyType == "int32":
             return "INTEGER"
         elif pyType == "int64":
-            return "INTEGER"
+            return "LONG"
+        elif pyType == "float":
+            return "FLOAT"
         elif pyType == "float32":
             return "FLOAT"
         elif pyType == "float64":
-            return "FLOAT"
+            return "DOUBLE"
         elif pyType == "bool":
             return "BOOLEAN"
+        elif pyType == "datetime":
+            return "DATETIME"
+        elif pyType == "datetime64":
+            return "DATETIME"
         else:
             return None
 
